---
name: Generic issue
about: For issues that do not fit any of the other categories. If this doesn’t work
  right, [choose a different type]( https://github.com/deepmodeling/dpgen/issues/new/choose).
title: _Replace With a Descriptive Title_
labels: wontfix
assignees: ''

---

**Summary**

<!--Please provide a clear and concise description of what the question is.-->

**DPGEN Version and Platform**

<!--Please specify precisely which DPGEN version this issue was detected with ("import dpgen" in the python command line interface and type "print(dpgen.__version__)") and what platform (operating system and its version, hardware) you are running on.-->

**Job submission and computing cluster configuration**

<!--If the question is about job submission, Please specify your jobs submission system and your authority. If applicable, specify your computing system configurations as well.-->

**Details**

<!--Please explain the issue in detail here-->
